<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AutoUpdater</name>
    <message>
        <source>No ssl configuration!
OpenSSL might not be installed.</source>
        <translation>未找到 SSL 配置！
您可能没有安装 OpenSSL。</translation>
    </message>
    <message>
        <source>Failed to save the Birdtray installer:
</source>
        <translation>安装程序保存失败：
</translation>
    </message>
    <message>
        <source>Failed to download the Birdtray installer:
</source>
        <translation>安装程序下载失败：
</translation>
    </message>
    <message>
        <source>Installer download failed</source>
        <translation>安装程序下载失败</translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation>更新失败</translation>
    </message>
    <message>
        <source>Failed to start the Birdtray installer.</source>
        <translation>启动 Birdtray 安装程序失败。</translation>
    </message>
</context>
<context>
    <name>BirdtrayApp</name>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation>一个为 Thunderbird 提供最小化到系统托盘及新邮件提醒功能的自由软件。</translation>
    </message>
    <message>
        <source>Display the contents of the given mork database.</source>
        <translation>显示指定 Mork 数据库的内容。</translation>
    </message>
    <message>
        <source>databaseFile</source>
        <translation>数据库文件</translation>
    </message>
    <message>
        <source>Decode an IMAP Utf7 string.</source>
        <translation>解析 UTF7 编码的 IMAP 字符串。</translation>
    </message>
    <message>
        <source>string</source>
        <translation>字符串</translation>
    </message>
    <message>
        <source>Show the settings.</source>
        <translation>显示配置项。</translation>
    </message>
    <message>
        <source>Reset the settings to the defaults.</source>
        <translation>重置为默认设置。</translation>
    </message>
    <message>
        <source>Toggle the Thunderbird window.</source>
        <translation>显示 / 隐藏 Thunderbird 窗口。</translation>
    </message>
    <message>
        <source>Show the Thunderbird window.</source>
        <translation>显示 Thunderbird 窗口。</translation>
    </message>
    <message>
        <source>Hide the Thunderbird window.</source>
        <translation>隐藏 Thunderbird 窗口。</translation>
    </message>
    <message>
        <source>Write log to a file.</source>
        <translation>将日志写入文件。</translation>
    </message>
    <message>
        <source>file</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Sorry, the system tray cannot be controlled by this add-on on your operating system.</source>
        <translation>抱歉，您的操作系统不支持通过本程序控制系统托盘。</translation>
    </message>
</context>
<context>
    <name>DialogAddEditNewEmail</name>
    <message>
        <source>&quot;New Email&quot; Entry</source>
        <translation>新建发件模板</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名称：</translation>
    </message>
    <message>
        <source>(Optional) Prefilled fields</source>
        <translation>预设字段（可选）</translation>
    </message>
    <message>
        <source>Email subject:</source>
        <translation>邮件主题：</translation>
    </message>
    <message>
        <source>Email message text:</source>
        <translation>邮件正文：</translation>
    </message>
    <message>
        <source>Email recipient:</source>
        <translation>收件人：</translation>
    </message>
    <message>
        <source>No name specified</source>
        <translation>未命名</translation>
    </message>
    <message>
        <source>The name cannot be empty.</source>
        <translation>模板名称不能为空。</translation>
    </message>
</context>
<context>
    <name>DialogLogOutput</name>
    <message>
        <source>Debug log viewer</source>
        <translation>调试日志</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <source>Birdtray Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>New Mail Notification</source>
        <translation>新邮件通知</translation>
    </message>
    <message>
        <source>Show unread count</source>
        <translation>显示未读邮件数</translation>
    </message>
    <message>
        <source>Different icon when unread:</source>
        <translation>有未读邮件时使用图标：</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Fastest</source>
        <translation>最快</translation>
    </message>
    <message>
        <source>Icon (Ctrl-click to reset):</source>
        <translation>图标（按住 Ctrl 点击以重置）：</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This notification color will be used when more than one monitored account has unread emails.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;在多个信箱有未读邮件时使用该颜色。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Multiple notification color:</source>
        <translation>多信箱未读通知颜色：</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This changes the font thickness, i.e. makes the font bold.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;设置字体粗细。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Blinking speed:</source>
        <translation>图标闪烁速度：</translation>
    </message>
    <message>
        <source>Font style:</source>
        <translation>字体：</translation>
    </message>
    <message>
        <source>Bold:</source>
        <translation>加粗：</translation>
    </message>
    <message>
        <source>Notification border color:</source>
        <translation>通知消息边框颜色：</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>None</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Monitoring</source>
        <translation>信箱</translation>
    </message>
    <message>
        <source>Accounts to monitor</source>
        <translation>信箱监听列表</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Allow ignoring the current unread email counter</source>
        <translation>添加“忽略当前未读”上下文菜单</translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Launching and Hiding</source>
        <translation>启动与隐藏</translation>
    </message>
    <message>
        <source>Start Thunderbird when Birdtray starts</source>
        <translation>启动 Birdtray 时自动启动 Thunderbird</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When both Thunderbird and Birdtray are set to start with the operating system, this usually results in two copies of Thunderbird being launched. Here you can add a delay before Thunderbird is launched, to prevent this.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;同时设置 Thunderbird 和 Birdtray 自启动可能导致 Thunderbird 启动两个实例。您可以为 Birdtray 启动 Thunderbird 设置一个延迟来避免这点。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> second delay</source>
        <translation> 秒</translation>
    </message>
    <message>
        <source>with a </source>
        <translation>并延迟 </translation>
    </message>
    <message>
        <source>and hide it</source>
        <translation>启动时隐藏</translation>
    </message>
    <message>
        <source>Terminate Thunderbird when quitting Birdtray</source>
        <translation>退出 Birdtray 时关闭 Thunderbird</translation>
    </message>
    <message>
        <source>Hide/show Thunderbird window when clicking on tray icon</source>
        <translation>点击托盘图标时显示 / 隐藏 Thunderbird 窗口</translation>
    </message>
    <message>
        <source>Hide Thunderbird window when it is minimized</source>
        <translation>Thunderbird 最小化时自动隐藏</translation>
    </message>
    <message>
        <source>Show red X in tray icon if Thunderbird is not running</source>
        <translation>Thunderbird 未运行时在托盘图标上显示红色的 X 符号</translation>
    </message>
    <message>
        <source>Restart Thunderbird if it was closed</source>
        <translation>Thunderbird 被关闭时自动重启</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>发件模板</translation>
    </message>
    <message>
        <source>Enable New Email submenu</source>
        <translation>启用“发件模板”托盘图标菜单</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <source>Please do not change these settings unless you understand what you&apos;re doing.</source>
        <translation>修改以下配置前请确保您清楚是否真的需要修改它们。</translation>
    </message>
    <message>
        <source>Thunderbird window name pattern:</source>
        <translation>Thunderbird 窗口标题模板：</translation>
    </message>
    <message>
        <source>Minimum notification font size:</source>
        <translation>通知消息字体不小于：</translation>
    </message>
    <message>
        <source> points</source>
        <translation> 像素</translation>
    </message>
    <message>
        <source>When blinking, use the fade-in/fade-out transition (increases CPU use!)</source>
        <translation>图标闪烁时启用淡入淡出动画（会增加 CPU 消耗）</translation>
    </message>
    <message>
        <source>Make the system tray icon</source>
        <translation>有新邮件时以</translation>
    </message>
    <message>
        <source>Check for new updates when Birdtray starts.</source>
        <translation>当 Birdtray 启动时检查是否有新版本。</translation>
    </message>
    <message>
        <source>Check for new updates on startup</source>
        <translation>启动时检查更新</translation>
    </message>
    <message>
        <source>Check for a new Birdtray version.</source>
        <translation>检测是否有新版本。</translation>
    </message>
    <message>
        <source>Check now</source>
        <translation>立即检查</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Version check failed</source>
        <translation>检测失败</translation>
    </message>
    <message>
        <source>Failed to check for a new Birdtray version:
</source>
        <translation>检查新版本失败：
</translation>
    </message>
    <message>
        <source>Checking...</source>
        <translation>正在检测...</translation>
    </message>
    <message>
        <source>Choose the new icon</source>
        <translation>选择图标</translation>
    </message>
    <message>
        <source>Images (*.png *.svg *.svgz)</source>
        <translation>图像 (*.png *.svg *.svgz)</translation>
    </message>
    <message>
        <source>Invalid icon</source>
        <translation>无效图标</translation>
    </message>
    <message>
        <source>Could not load the icon from this file.</source>
        <translation>无法加载图标。</translation>
    </message>
    <message>
        <source>Thunderbird command line:</source>
        <translation>Thunderbird 启动命令：</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This is the full command-line (with arguments) which will be used to start Thunderbird. Arguments are space-separated, but spaces in quotes are allowed, i.e. something like &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; will work.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;启动 Thunderbird 的完整命令，将以此启动 Thunderbird。启动参数以空格分隔，但本身包含空格的参数必须用引号包裹。例如：&lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Ignore all unread email that are present when Birdtray starts. Only new emails will be taken into account by the unread counter.</source>
        <translation>Birdtray 启动时忽略当前的未读邮件，未读计数将仅计算新收到的邮件。</translation>
    </message>
    <message>
        <source>opaque when new mail is present,</source>
        <translation>的透明度显示图标，</translation>
    </message>
    <message>
        <source>hide it if no new mail is present.</source>
        <translation>没有未读邮件时隐藏托盘图标。</translation>
    </message>
    <message>
        <source>Choose one or more MSF files</source>
        <translation>选择一个或多个 MSF 文件：</translation>
    </message>
    <message>
        <source>Mail Index (*.msf)</source>
        <translation>邮件摘要文件 (*.msf)</translation>
    </message>
    <message>
        <source>No new updates found</source>
        <translation>已经是最新版本</translation>
    </message>
    <message>
        <source>Show log window</source>
        <translation>查看日志</translation>
    </message>
    <message>
        <source>Force index file re-read every</source>
        <translation>强制重载索引文件，每隔</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> 秒</translation>
    </message>
    <message>
        <source>Translations are powered by the community:</source>
        <translation>翻译工作由社区支持：</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>译者</translation>
    </message>
    <message>
        <source>Active maintainers</source>
        <translation>活跃贡献者</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>贡献者</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If this box is checked, the Birdtray icon will show the number of unread emails.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;If it is unchecked, no count will be shown, and you will only know about unread emails because of the blinking or different icon, depending on your settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;如果勾选此项，将在图标上显示未读邮件数。&lt;/p&gt;&lt;p&gt;&lt;br/&gt;如果取消勾选，则您只能通过图标闪烁或改变来判断是否有新邮件，这取决于您的配置。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Unread change cmd:</source>
        <translation>未读邮件变化时执行脚本：</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select mail folders for watching.&lt;br/&gt;&lt;br/&gt;If the dialog doesn&apos;t show your folder, &lt;i&gt;Ctrl + Shift click&lt;/i&gt; to open a file selection dialog that allows adding any mork file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;选择要监听的邮件目录。&lt;br/&gt;&lt;br/&gt;如果文件对话框中没有显示你想要的目录，通过 &lt;i&gt;Ctrl + Shift click&lt;/i&gt; 打开可以选择任意文件的对话框。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Could not load the icon from this file. Try loading the icon in an image editing tool and saving it in a different format.</source>
        <translation>无法加载图标，可尝试将其转换为其他格式后再试。</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If not empty, this command will be invoked every time the unread counter changes (including when it becomes zero). It is invoked via shell, as-is, with %NEW% replaced by the new unread count value and %OLD% replaced with the old unread count value (which may be the same as new).&lt;/p&gt;&lt;p&gt;Most users don&apos;t need this functionality and should leave it empty.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;如果非空，当未读计数改变（包括归零）时将通过 shell 执行该命令。您可以在命令中使用 %NEW% 和 %OLD% 引用新的未读计数和旧的未读计数。&lt;/p&gt;&lt;p&gt;大多数用户不会用到此功能，除非您确实需要，否则请将其留空。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Support non-NETWM compliant WMs</source>
        <translation>支持非 NETWM 兼容的窗口管理器</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your desktop manager is not fully NETWM compliant, you may need to check this checkbox so it can detect Thunderbird window and is able to minimise and hide it.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;如果您的桌面环境不是 NETWM 兼容的，您可能需要勾选此项才能允许桌面环境正确探测 Thunderbird 并将其最小化和隐藏。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If enabled, this option adds the &amp;quot;Ignore currently unread emails&amp;quot; action to the context menu. This action allows you to ignore the emails which are currently unread. Birdtray would then pretend there are no unread emails left, and would only show new emails over the ignored count.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;For example, if there were 10 unread emails, and you clicked on &amp;quot;Ignore&amp;quot; action, Birdtray will show no unread email indicator as long as unread email count remains at 10. Once new email is received and you have 11 total unread emails, Birdtray will show the new email count as 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;勾选此项会将&amp;quot;忽略当前未读邮件&amp;quot;添加到右键菜单。该动作允许您忽略当前的未读邮件；Birdtray 会伪装成已经没有未读邮件，且只将此后的新邮件纳入未读计数。&lt;/p&gt;&lt;p&gt;&lt;br/&gt;例如，如果您在有 10 封未读邮件时执行&amp;quot;忽略&amp;quot;动作，只要未读邮件数仍为 10 封，Birdtray 就会在计数器显示没有未读邮件。此后如果收到一封新邮件、总未读邮件数变为 11，Birdtray 将在计数器显示有 1 封未读邮件。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>At startup</source>
        <translation>启动时</translation>
    </message>
    <message>
        <source>When hiding Thunderbird</source>
        <translation>隐藏 Thunderbird 时</translation>
    </message>
    <message>
        <source>When showing Thunderbird</source>
        <translation>显示 Thunderbird 时</translation>
    </message>
    <message>
        <source>Start Thunderbird by clicking on the tray icon if it was closed</source>
        <translation>如果 Thunderbird 已关闭，在点击托盘图标时启动 Thunderbird</translation>
    </message>
    <message>
        <source>When detecting a change, wait</source>
        <translation>检测到变更时，等待</translation>
    </message>
    <message>
        <source> milliseconds</source>
        <translation> 毫秒</translation>
    </message>
    <message>
        <source>before updating the unread counter.</source>
        <translation>后再更新未读邮件计数器。</translation>
    </message>
    <message>
        <source>Thunderbird process name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray version [VERSION] compiled at [DATE] using Qt [QT_VERSION].&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is FREE SOFTWARE, which is licensed under General Public License v3. To clarify further, you can use it for any purpose, including commercial, without paying anything. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;To ask for help, request a feature or report a bug use the &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github project page&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;For those of you who appreciate my work on Birdtray, which is being developed in my free time, you can do it here: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Thank you for your continuous support!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray[VERSION]，编译于[DATE]，使用 Qt [QT_VERSION]。&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray是签署在GPLv3（General Public License v3）下的自由软件，您可以以任何目的使用它，包括商业使用，而不需要支付任何代价。&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;寻求帮助、新功能建议和bug通告请访问&lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github项目仓库&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;。&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;birdtray是作者利用空闲时间开发，如果您喜欢这个作品，可以通过通过此链接打赏：&lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;感谢您的支持！&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <source>Fatal</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Fatal error: %1

Log file is written into file %2</source>
        <translation>严重错误：%1

详情见日志文件 %2</translation>
    </message>
    <message>
        <source>Failed to open log file %1: %2</source>
        <translation>打开日志文件 %1 失败：%2</translation>
    </message>
</context>
<context>
    <name>MailAccountDialog</name>
    <message>
        <source>Choose the Thunderbird profiles path</source>
        <translation>选择 Thunderbird 数据目录</translation>
    </message>
    <message>
        <source>No folder selected</source>
        <translation>未选择目录</translation>
    </message>
    <message>
        <source>No mail folder was selected to monitor.
Do you want to continue?</source>
        <translation>未选择任何要监听的邮件目录。
是否继续？</translation>
    </message>
    <message>
        <source>Select Accounts</source>
        <translation>选择信箱</translation>
    </message>
    <message>
        <source>Select the directory that contains the Thunderbird profiles.</source>
        <translation>请选择 Thunderbird 数据目录。</translation>
    </message>
    <message>
        <source>Thunderbird Profiles Directory</source>
        <translation>Thunderbird 数据目录</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Select the mail accounts you want to monitor.</source>
        <translation>选择您要监听的信箱。</translation>
    </message>
    <message>
        <source>Email Folder</source>
        <translation>信箱目录</translation>
    </message>
    <message>
        <source>Notification Color</source>
        <translation>通知消息颜色</translation>
    </message>
    <message>
        <source>If you monitor multiple folders, the default notification color is used to show the sum of all unread mails.</source>
        <translation>如果您选择了多个目录，将使用默认颜色显示未读邮件总数。</translation>
    </message>
    <message>
        <source>%1 (Profile)</source>
        <translation>%1（Profile）</translation>
    </message>
    <message>
        <source>No mail profiles were found.
Please make sure you selected the correct profiles directory.</source>
        <translation>未找到 Thunderbird 配置。
请检查您选择的 Thunderbird 数据目录是否正确。</translation>
    </message>
</context>
<context>
    <name>ModelAccountTree</name>
    <message>
        <source>Account</source>
        <translation>信箱</translation>
    </message>
    <message>
        <source>Notification color</source>
        <translation>通知颜色</translation>
    </message>
</context>
<context>
    <name>ModelNewEmails</name>
    <message>
        <source>Menu entry item</source>
        <translation>发件模板</translation>
    </message>
</context>
<context>
    <name>MorkParser</name>
    <message>
        <source>Couldn&apos;t open file: </source>
        <translatorcomment>checkTranslation ignore: whitespace_end_src_diff</translatorcomment>
        <translation>无法打开文件：</translation>
    </message>
    <message>
        <source>Unsupported version.</source>
        <translation>抱歉，该版本不受支持。</translation>
    </message>
    <message>
        <source>Invalid format.</source>
        <translation>无效的格式。</translation>
    </message>
    <message>
        <source>Parsing error.</source>
        <translation>匹配出错。</translation>
    </message>
    <message>
        <source>Unexpected EOF.</source>
        <translation>未预期的文件结束标志符（EOF）。</translation>
    </message>
    <message>
        <source>Invalid comment.</source>
        <translation>无效的注释。</translation>
    </message>
    <message>
        <source>Format error.</source>
        <translation>格式错误。</translation>
    </message>
    <message>
        <source>Unexpected end of group.</source>
        <translation>未预期的 end-group。</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Could not save the settings</source>
        <translation>无法保存设置</translation>
    </message>
    <message>
        <source>Could not save the settings into file %1:
%2</source>
        <translation>无法写入配置到文件 %1：
%2</translation>
    </message>
    <message>
        <source>Sqlite based accounts migrated</source>
        <translation>成功迁移基于 SQLite 的帐号信息</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail folders using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser, but some configured mail folders could not be found.</source>
        <translation>您正在监听使用 SQLite 解析器的信箱，但该解析器已被弃用。这些监听设置已自动改用 Mork 解析器，但一些已配置的信箱无法找到。</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail accounts using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser. Please verify that all accounts were mapped correctly.</source>
        <translation>您正在监听使用 SQLite 解析器的邮箱帐号，但该解析器已被弃用。这些监听设置已自动改用 Mork 解析器，请确认各帐号映射是否正确。</translation>
    </message>
    <message>
        <source>Cannot load default system tray icon.</source>
        <translation>无法加载默认托盘图标。</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Would you like to set up Birdtray?</source>
        <translation>您要对 Birdtray 进行配置吗？</translation>
    </message>
    <message>
        <source>You have not yet configured any email folders to monitor. Would you like to do it now?</source>
        <translation>您尚未配置任何要监听的信箱，是否现在配置？</translation>
    </message>
    <message>
        <source>Show Thunderbird</source>
        <translation>显示 Thunderbird</translation>
    </message>
    <message>
        <source>Hide Thunderbird</source>
        <translation>隐藏 Thunderbird</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>发件模板</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>空</translation>
    </message>
    <message>
        <source>New Email Message</source>
        <translation>新建邮件</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 分钟</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 分钟</translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation>30 分钟</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>1 小时</translation>
    </message>
    <message>
        <source>4 hours</source>
        <translation>4 小时</translation>
    </message>
    <message>
        <source>Snooze for ...</source>
        <translation>暂停通知...</translation>
    </message>
    <message>
        <source>Unsnooze</source>
        <translation>启用通知</translation>
    </message>
    <message>
        <source>Ignore unread emails</source>
        <translation>忽略当前未读邮件</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>设置...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Cannot start Thunderbird</source>
        <translation>启动 Thunderbird 失败</translation>
    </message>
    <message>
        <source>Error starting Thunderbird, because we could not attach to the updater:

%1</source>
        <translation>启动 Thunderbird 失败，因为无法附载到更新程序：

%1</translation>
    </message>
    <message>
        <source>Ignore unread emails (now %1)</source>
        <translation>忽略当前未读邮件（%1 封）</translation>
    </message>
    <message>
        <source>Error starting Thunderbird as &apos;%1 %2&apos;:

%3</source>
        <translation>以‘%1 %2’启动 Thunderbird 失败：

%3</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>警告：%1</translation>
    </message>
    <message>
        <source>Don&apos;t ask again</source>
        <translation>不再询问</translation>
    </message>
</context>
<context>
    <name>UnreadMonitor</name>
    <message>
        <source>Unable to watch %1 for changes.</source>
        <translation>无法监听 %1。</translation>
    </message>
    <message>
        <source>Unable to read from %1.</source>
        <translation>无法读取 %1。</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Current version:</source>
        <translation>当前版本：</translation>
    </message>
    <message>
        <source>A new version of Birdtray is available.</source>
        <translation>有新版本可用。</translation>
    </message>
    <message>
        <source>New version:</source>
        <translation>新版本：</translation>
    </message>
    <message>
        <source>Download size:</source>
        <translation>下载文件大小：</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Ignore this version</source>
        <translation>忽略此版本</translation>
    </message>
    <message>
        <source>ca. %1 Mb</source>
        <translation>约 %1 Mb</translation>
    </message>
    <message>
        <source>Update and restart</source>
        <translation>更新并重启</translation>
    </message>
</context>
<context>
    <name>UpdateDownloadDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Downloading Birdtray update...</source>
        <translation>正在下载更新...</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>后台运行</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer...</source>
        <translation>正在下载文件...</translation>
    </message>
    <message>
        <source>Download finished. Restart and update Birdtray?</source>
        <translation>下载完成。是否立即重启以应用更新？</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer... (%1 Mb / %2 Mb).</source>
        <translatorcomment>checkTranslation ignore: punctuation_end_differ</translatorcomment>
        <translation>正在下载文件...（%1 Mb / %2 Mb）</translation>
    </message>
</context>
</TS>
